@@ -1,7 +1,7 @@
 /*
  * This file is part of MaePad
- * Copyright (c) 2010 Thomas Perl <thp@thpinfo.com>
- * http://thpinfo.com/2010/maepad/
+ * Copyright (c) 2010 Thomas Perl <thp.io/about>
+ * http://thp.io/2010/maepad/
  *
  * Based on Maemopad+:
  * Copyright (c) 2006-2008 Kemal Hadimli
@@ -121,6 +121,12 @@ MainView *interface_main_view_new(AppData * data)
         data->main_view = HILDON_STACKABLE_WINDOW(hildon_stackable_window_new());
         data->node_view = HILDON_STACKABLE_WINDOW(hildon_stackable_window_new());
 
+        /* Enable auto-rotation on Maemo 5 (automatic since PR1.2?) */
+        hildon_gtk_window_set_portrait_flags(data->main_view,
+                HILDON_PORTRAIT_MODE_SUPPORT);
+        hildon_gtk_window_set_portrait_flags(data->node_view,
+                HILDON_PORTRAIT_MODE_SUPPORT);
+
         /* Fullscreen and toolbar handling for the node view window */
         g_signal_connect(G_OBJECT(data->node_view),
                          "window-state-event",
@@ -184,7 +190,7 @@ MainView *interface_main_view_new(AppData * data)
 
 	gtk_box_pack_start(GTK_BOX(main_vbox), result->scrolledwindow, TRUE, TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(main_vbox), sketchwidget_get_mainwidget(result->sk), TRUE, TRUE, 0);
-	gtk_box_pack_start(GTK_BOX(main_vbox), result->listscroll, TRUE, TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(main_vbox), result->checklist_content, TRUE, TRUE, 0);
 	hildon_window_add_toolbar(HILDON_WINDOW(result->data->node_view), GTK_TOOLBAR(result->toolbar));
 
         gtk_container_add(GTK_CONTAINER(data->node_view), main_vbox);
@@ -948,13 +954,26 @@ void create_treeview(MainView * main)
 
 void create_checklist(MainView * main)
 {
+        main->checklist_content = gtk_vbox_new(FALSE, 0);
 	main->listscroll = hildon_pannable_area_new();
 
+        gtk_box_pack_start(GTK_BOX(main->checklist_content),
+                main->listscroll, TRUE, TRUE, 0);
+
+        main->checklist_empty_label = gtk_label_new(_("No items"));
+        hildon_helper_set_logical_font(main->checklist_empty_label,
+                "LargeSystemFont");
+        hildon_helper_set_logical_color(main->checklist_empty_label,
+                GTK_RC_FG, GTK_STATE_NORMAL, "SecondaryTextColor");
+        gtk_misc_set_alignment(GTK_MISC(main->checklist_empty_label),
+                .5, .5);
+
+        gtk_box_pack_start(GTK_BOX(main->checklist_content),
+                main->checklist_empty_label, TRUE, TRUE, 0);
+
         /* Detect scrolling to abort longpress action on checklist */
         g_signal_connect(G_OBJECT(main->listscroll), "panning-started", G_CALLBACK(on_checklist_start_panning), main);
 
-	gtk_widget_hide(main->listscroll);
-
 	GtkListStore *store = gtk_list_store_new(CHECKN_COLUMNS, G_TYPE_BOOLEAN, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INT, G_TYPE_BOOLEAN, G_TYPE_STRING);
 
 	main->listview = hildon_gtk_tree_view_new_with_model(HILDON_UI_MODE_EDIT, GTK_TREE_MODEL(store));
@@ -1008,7 +1027,8 @@ void create_checklist(MainView * main)
         g_signal_connect(main->listview, "button-release-event", G_CALLBACK(on_checklist_button_release), main);
 
 	gtk_container_add(GTK_CONTAINER(main->listscroll), main->listview);
-	gtk_widget_show(main->listview);
+	gtk_widget_show_all(main->checklist_content);
+        gtk_widget_hide(main->listscroll);
 /*
 GtkTreeIter    toplevel;
 gtk_list_store_append(store, &toplevel);
