@@ -1,7 +1,7 @@
 /*
  * This file is part of MaePad
- * Copyright (c) 2010 Thomas Perl <thp@thpinfo.com>
- * http://thpinfo.com/2010/maepad/
+ * Copyright (c) 2010 Thomas Perl <thp.io/about>
+ * http://thp.io/2010/maepad/
  *
  * Based on Maemopad+:
  * Copyright (c) 2006-2008 Kemal Hadimli
@@ -220,8 +220,11 @@ struct _MainView
 		WPTextBuffer *buffer;			/* buffer that contains the text */
 		GtkClipboard *clipboard;		/* clipboard for copy/paste */
 
+                GtkWidget *checklist_content; /* all checklist contents */
+                GtkWidget *checklist_empty_label; /* The "No items" label for empty checklists */
 		GtkWidget *listscroll;	/* checklist is under this widget */
 		GtkWidget *listview; /*checklist */
+
 		GtkTreeViewColumn* checklist_column_check;
 		GtkTreeViewColumn* checklist_column_text;
                 guint checklist_longpress_source_id; /* longpress timeout id */
